@@ -33,6 +33,7 @@
 #include "gda-dict.h"
 #include "gda-parameter-list.h"
 #include "gda-value.h"
+#include "gda-enum-types.h"
 
 typedef struct {
 	GModule              *handle;
@@ -41,7 +42,6 @@ typedef struct {
 	/* entry points to the plugin */
 	const gchar        *(*plugin_get_name) (void);
 	const gchar        *(*plugin_get_description) (void);
-	GList              *(*plugin_get_connection_params) (void);
 	GdaServerProvider  *(*plugin_create_provider) (void);
 	gchar              *(*get_dsn_spec) (void);
 } LoadedProvider;
@@ -184,8 +184,8 @@ gda_client_class_init (GdaClientClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GdaClientClass, event_notification),
 			      NULL, NULL,
-			      gda_marshal_VOID__POINTER_INT_POINTER,
-			      G_TYPE_NONE, 3, G_TYPE_POINTER, G_TYPE_INT, G_TYPE_POINTER);
+			      gda_marshal_VOID__OBJECT_ENUM_OBJECT,
+			      G_TYPE_NONE, 3, GDA_TYPE_CONNECTION, GDA_TYPE_CLIENT_EVENT, GDA_TYPE_PARAMETER_LIST);
 
 	object_class->finalize = gda_client_finalize;
 }
@@ -311,8 +311,6 @@ find_or_load_provider (GdaClient *client, const gchar *provider)
 			 (gpointer) &prv->plugin_get_name);
 	g_module_symbol (prv->handle, "plugin_get_description",
 			 (gpointer) &prv->plugin_get_description);
-	g_module_symbol (prv->handle, "plugin_get_connection_params",
-			 (gpointer) &prv->plugin_get_connection_params);
 	g_module_symbol (prv->handle, "plugin_create_provider",
 			 (gpointer) &prv->plugin_create_provider);
 	g_module_symbol (prv->handle, "plugin_get_dsn_spec",
@@ -334,7 +332,7 @@ find_or_load_provider (GdaClient *client, const gchar *provider)
 		return NULL;
 	}
 	
-	g_object_ref (G_OBJECT (prv->provider)); /* vivien: usefull? */
+	g_object_ref (G_OBJECT (prv->provider));
 	g_object_weak_ref (G_OBJECT (prv->provider), (GWeakNotify) provider_weak_cb, client);
 	g_hash_table_insert (client->priv->providers,
 			     g_strdup (provider),
@@ -508,7 +506,7 @@ gda_client_open_connection_from_string (GdaClient *client,
 					GError **error)
 {
 	LoadedProvider *prv;
-	GdaConnection *cnc;
+	GdaConnection *cnc = NULL;
 	GList *l;
 
 	g_return_val_if_fail (GDA_IS_CLIENT (client), NULL);
@@ -742,112 +740,12 @@ gda_client_notify_connection_closed_event (GdaClient *client, GdaConnection *cnc
 	gda_client_notify_event (client, cnc, GDA_CLIENT_EVENT_CONNECTION_CLOSED, NULL);
 }
 
-/**
- * gda_client_notify_transaction_started_event
- * @client: a #GdaClient object.
- * @cnc: a #GdaConnection object.
- * @xaction: a #GdaTransaction object.
- *
- * Notifies the given #GdaClient of the #GDA_CLIENT_EVENT_TRANSACTION_STARTED
- * event.
- */
-void
-gda_client_notify_transaction_started_event (GdaClient *client, GdaConnection *cnc, GdaTransaction *xaction)
-{
-	GdaParameterList *params;
-	GdaParameter *param;
-	GValue *value;
-
-	g_return_if_fail (GDA_IS_CLIENT (client));
-	g_return_if_fail (GDA_IS_CONNECTION (cnc));
-	g_return_if_fail (GDA_IS_TRANSACTION (xaction));
-
-	param = gda_parameter_new (G_TYPE_OBJECT);
-	gda_object_set_name (GDA_OBJECT (param), "transaction");
-	value = g_value_init (g_new0 (GValue, 1), G_TYPE_OBJECT);
-	g_value_set_object (value, G_OBJECT (xaction));
-	gda_parameter_set_value (param, value);
-	gda_value_free (value);
-
-	params = gda_parameter_list_new (NULL);
-	gda_parameter_list_add_param (params, param);
-	g_object_unref (param);
-	gda_client_notify_event (client, cnc, GDA_CLIENT_EVENT_TRANSACTION_STARTED, params);
-	g_object_unref (params);
-}
-
-/**
- * gda_client_notify_transaction_committed_event
- * @client: a #GdaClient object.
- * @cnc: a #GdaConnection object.
- * @xaction: a #GdaTransaction object.
- *
- * Notifies the given #GdaClient of the #GDA_CLIENT_EVENT_TRANSACTION_COMMITTED
- * event.
- */
-void
-gda_client_notify_transaction_committed_event (GdaClient *client, GdaConnection *cnc, GdaTransaction *xaction)
-{
-	GdaParameterList *params;
-	GdaParameter *param;
-	GValue *value;
-
-	g_return_if_fail (GDA_IS_CLIENT (client));
-	g_return_if_fail (GDA_IS_CONNECTION (cnc));
-	g_return_if_fail (GDA_IS_TRANSACTION (xaction));
-
-	param = gda_parameter_new (G_TYPE_OBJECT);
-	gda_object_set_name (GDA_OBJECT (param), "transaction");
-	value = g_value_init (g_new0 (GValue, 1), G_TYPE_OBJECT);
-	g_value_set_object (value, G_OBJECT (xaction));
-	gda_parameter_set_value (param, value);
-	gda_value_free (value);
-
-	params = gda_parameter_list_new (NULL);
-	gda_parameter_list_add_param (params, param);
-	g_object_unref (param);
-	gda_client_notify_event (client, cnc, GDA_CLIENT_EVENT_TRANSACTION_COMMITTED, params);
-	g_object_unref (params);
-}
-
-/**
- * gda_client_notify_transaction_cancelled_event
- * @client: a #GdaClient object.
- * @cnc: a #GdaConnection object.
- * @xaction: a #GdaTransaction object.
- *
- * Notifies the given #GdaClient of the #GDA_CLIENT_EVENT_TRANSACTION_CANCELLED 
- * event.
- */
-void
-gda_client_notify_transaction_cancelled_event (GdaClient *client, GdaConnection *cnc, GdaTransaction *xaction)
-{
-	GdaParameterList *params;
-	GdaParameter *param;
-	GValue *value;
-
-	g_return_if_fail (GDA_IS_CLIENT (client));
-	g_return_if_fail (GDA_IS_CONNECTION (cnc));
-	g_return_if_fail (GDA_IS_TRANSACTION (xaction));
-
-	param = gda_parameter_new (G_TYPE_OBJECT);
-	gda_object_set_name (GDA_OBJECT (param), "transaction");
-	value = g_value_init (g_new0 (GValue, 1), G_TYPE_OBJECT);
-	g_value_set_object (value, G_OBJECT (xaction));
-	gda_parameter_set_value (param, value);
-	gda_value_free (value);
-
-	params = gda_parameter_list_new (NULL);
-	gda_parameter_list_add_param (params, param);
-	g_object_unref (param);
-	gda_client_notify_event (client, cnc, GDA_CLIENT_EVENT_TRANSACTION_CANCELLED, params);
-	g_object_unref (params);
-}
-
 /**
  * gda_client_begin_transaction
  * @client: a #GdaClient object.
- * @xaction: a #GdaTransaction object.
+ * @name: the name of the transation to start
+ * @level:
+ * @error: a place to store errors, or %NULL
  *
  * Starts a transaction on all connections being managed by the given
  * #GdaClient. It is important to note that this operates on all
@@ -862,16 +760,16 @@ gda_client_notify_transaction_cancelled_event (GdaClient *client, GdaConnection
  * or %FALSE if one of them fails.
  */
 gboolean
-gda_client_begin_transaction (GdaClient *client, GdaTransaction *xaction)
+gda_client_begin_transaction (GdaClient *client, const gchar *name, GdaTransactionIsolation level,
+			      GError **error)
 {
 	GList *l;
 
 	g_return_val_if_fail (GDA_IS_CLIENT (client), FALSE);
-	g_return_val_if_fail (GDA_IS_TRANSACTION (xaction), FALSE);
 
 	for (l = client->priv->connections; l != NULL; l = l->next) {
-		if (!gda_connection_begin_transaction (GDA_CONNECTION (l->data), xaction)) {
-			gda_client_rollback_transaction (client, xaction);
+		if (!gda_connection_begin_transaction (GDA_CONNECTION (l->data), name, level, error)) {
+			gda_client_rollback_transaction (client, name, NULL);
 			return FALSE;
 		}
 	}
@@ -882,7 +780,8 @@ gda_client_begin_transaction (GdaClient *client, GdaTransaction *xaction)
 /**
  * gda_client_commit_transaction
  * @client: a #GdaClient object.
- * @xaction: a #GdaTransaction object.
+ * @name: the name of the transation to commit
+ * @error: a place to store errors, or %NULL
  *
  * Commits a running transaction on all connections being managed by the given
  * #GdaClient. It is important to note that this operates on all
@@ -897,16 +796,15 @@ gda_client_begin_transaction (GdaClient *client, GdaTransaction *xaction)
  * or %FALSE if one of them fails.
  */
 gboolean
-gda_client_commit_transaction (GdaClient *client, GdaTransaction *xaction)
+gda_client_commit_transaction (GdaClient *client, const gchar *name, GError **error)
 {
 	GList *l;
 
 	g_return_val_if_fail (GDA_IS_CLIENT (client), FALSE);
-	g_return_val_if_fail (GDA_IS_TRANSACTION (xaction), FALSE);
 
 	for (l = client->priv->connections; l != NULL; l = l->next) {
-		if (!gda_connection_commit_transaction (GDA_CONNECTION (l->data), xaction)) {
-			gda_client_rollback_transaction (client, xaction);
+		if (!gda_connection_commit_transaction (GDA_CONNECTION (l->data), name, error)) {
+			gda_client_rollback_transaction (client, name, NULL);
 			return FALSE;
 		}
 	}
@@ -917,7 +815,8 @@ gda_client_commit_transaction (GdaClient *client, GdaTransaction *xaction)
 /**
  * gda_client_rollback_transaction
  * @client: a #GdaClient object.
- * @xaction: a #GdaTransaction object.
+ * @name: the name of the transation to rollback
+ * @error: a place to store errors, or %NULL
  *
  * Cancels a running transaction on all connections being managed by the given
  * #GdaClient. It is important to note that this operates on all
@@ -932,16 +831,15 @@ gda_client_commit_transaction (GdaClient *client, GdaTransaction *xaction)
  * or %FALSE if one of them fails.
  */
 gboolean
-gda_client_rollback_transaction (GdaClient *client, GdaTransaction *xaction)
+gda_client_rollback_transaction (GdaClient *client, const gchar *name, GError **error)
 {
 	GList *l;
 	gint failures = 0;
 
 	g_return_val_if_fail (GDA_IS_CLIENT (client), FALSE);
-	g_return_val_if_fail (GDA_IS_TRANSACTION (xaction), FALSE);
 
 	for (l = client->priv->connections; l != NULL; l = l->next) {
-		if (!gda_connection_rollback_transaction (GDA_CONNECTION (l->data), xaction))
+		if (!gda_connection_rollback_transaction (GDA_CONNECTION (l->data), name, error))
 			failures++;
 	}
 
@@ -979,17 +877,21 @@ gda_client_get_dsn_specs (GdaClient *client, const gchar *provider)
 /**
  * gda_client_prepare_create_database
  * @client: a #GdaClient object.
+ * @db_name: the name of the database to create, or %NULL
  * @provider: a provider
  *
  * Creates a new #GdaServerOperation object which contains the specifications required
  * to create a database. Once these specifications provided, use 
  * gda_client_perform_create_database() to perform the database creation.
  *
+ * If @db_name is left %NULL, then the name of the database to create will have to be set in the
+ * returned #GdaServerOperation using gda_server_operation_set_value_at().
+ *
  * Returns: new #GdaServerOperation object, or %NULL if the provider does not support database
  * creation
  */
 GdaServerOperation *
-gda_client_prepare_create_database (GdaClient *client, const gchar *provider)
+gda_client_prepare_create_database (GdaClient *client, const gchar *db_name, const gchar *provider)
 {
 	LoadedProvider *prv;
 
@@ -999,10 +901,20 @@ gda_client_prepare_create_database (GdaClient *client, const gchar *provider)
 		return NULL;
 
 	prv = find_or_load_provider (client, provider);
-	if (prv && prv->provider) 
-		return gda_server_provider_create_operation (prv->provider, NULL, 
-							     GDA_SERVER_OPERATION_CREATE_DB, 
-							     NULL, NULL);
+	if (prv && prv->provider) {
+		GdaServerOperation *op;
+		op = gda_server_provider_create_operation (prv->provider, NULL, 
+							   GDA_SERVER_OPERATION_CREATE_DB, 
+							   NULL, NULL);
+		if (op) {
+			g_object_set_data_full (G_OBJECT (op), "_gda_provider_name", 
+						prv->provider, g_object_unref);
+			if (db_name)
+				gda_server_operation_set_value_at (op, db_name, 
+								   NULL, "/DB_DEF_P/DB_NAME");
+		}
+		return op;
+	}
 	else
 		return NULL;
 }
@@ -1010,17 +922,21 @@ gda_client_prepare_create_database (GdaClient *client, const gchar *provider)
 /**
  * gda_client_prepare_drop_database
  * @client: a #GdaClient object.
+ * @db_name: the name of the database to drop, or %NULL
  * @provider: a provider
  *
  * Creates a new #GdaServerOperation object which contains the specifications required
  * to drop a database. Once these specifications provided, use 
  * gda_client_perform_drop_database() to perform the database creation.
  *
+ * If @db_name is left %NULL, then the name of the database to drop will have to be set in the
+ * returned #GdaServerOperation using gda_server_operation_set_value_at().
+ *
  * Returns: new #GdaServerOperation object, or %NULL if the provider does not support database
  * destruction
  */
 GdaServerOperation *
-gda_client_prepare_drop_database (GdaClient *client, const gchar *provider)
+gda_client_prepare_drop_database (GdaClient *client, const gchar *db_name, const gchar *provider)
 {
 	LoadedProvider *prv;
 
@@ -1030,10 +946,20 @@ gda_client_prepare_drop_database (GdaClient *client, const gchar *provider)
 		return NULL;
 
 	prv = find_or_load_provider (client, provider);
-	if (prv && prv->provider) 
-		return gda_server_provider_create_operation (prv->provider, NULL,
-							     GDA_SERVER_OPERATION_DROP_DB, 
-							     NULL, NULL);
+	if (prv && prv->provider) {
+		GdaServerOperation *op;
+		op = gda_server_provider_create_operation (prv->provider, NULL,
+							   GDA_SERVER_OPERATION_DROP_DB, 
+							   NULL, NULL);
+		if (op) {
+			g_object_set_data_full (G_OBJECT (op), "_gda_provider_name", 
+						prv->provider, g_object_unref);
+			if (db_name)
+				gda_server_operation_set_value_at (op, db_name, 
+								   NULL, "/DB_DESC_P/DB_NAME");
+		}
+		return op;
+	}
 	else
 		return NULL;
 }
@@ -1041,30 +967,29 @@ gda_client_prepare_drop_database (GdaClient *client, const gchar *provider)
 /**
  * gda_client_perform_create_database
  * @client: a #GdaClient object.
- * @provider: a provider
- * @op: a #GdaServerOperation object obtained using gda_client_prepare_server_operation()
+ * @op: a #GdaServerOperation object obtained using gda_client_prepare_create_database()
  * @error: a place to store en error, or %NULL
  *
- * Creates a new database using the specifications in @op. 
+ * Creates a new database using the specifications in @op, which must have been obtained using
+ * gda_client_prepare_create_database ()
  *
  * Returns: TRUE if no error occurred and the database has been created
  */
 gboolean
-gda_client_perform_create_database (GdaClient *client, const gchar *provider, GdaServerOperation *op,
-				    GError **error)
+gda_client_perform_create_database (GdaClient *client, GdaServerOperation *op, GError **error)
 {
-	LoadedProvider *prv;
+	GdaServerProvider *provider;
 
 	g_return_val_if_fail (GDA_IS_CLIENT (client), FALSE);
 	g_return_val_if_fail (GDA_IS_SERVER_OPERATION (op), FALSE);
 
-	prv = find_or_load_provider (client, provider);
-	if (prv && prv->provider) 
-		return gda_server_provider_perform_operation (prv->provider, NULL, 
-							      op, error);
+	provider = g_object_get_data (G_OBJECT (op), "_gda_provider_name");
+	if (provider) 
+		return gda_server_provider_perform_operation (provider, NULL, op, error);
 	else {
 		g_set_error (error, GDA_CLIENT_ERROR, 0, 
-			     _("Could not find provider %s in the current setup"), provider); 
+			     _("Could not find operation's associated provider, "
+			       "did you use gda_client_prepare_create_database() ?")); 
 		return FALSE;
 	}
 }
@@ -1072,30 +997,29 @@ gda_client_perform_create_database (GdaClient *client, const gchar *provider, Gd
 /**
  * gda_client_perform_drop_database
  * @client: a #GdaClient object.
- * @provider: a provider
- * @op: a #GdaServerOperation object obtained using gda_client_prepare_server_operation()
+ * @op: a #GdaServerOperation object obtained using gda_client_prepare_drop_database()
  * @error: a place to store en error, or %NULL
  *
- * Destroys an existing database using the specifications in @op. 
+ * Destroys an existing database using the specifications in @op,  which must have been obtained using
+ * gda_client_prepare_drop_database ()
  *
  * Returns: TRUE if no error occurred and the database has been destroyed
  */
 gboolean
-gda_client_perform_drop_database (GdaClient *client, const gchar *provider, 
-				  GdaServerOperation *op, GError **error)
+gda_client_perform_drop_database (GdaClient *client, GdaServerOperation *op, GError **error)
 {
-	LoadedProvider *prv;
+	GdaServerProvider *provider;
 
 	g_return_val_if_fail (GDA_IS_CLIENT (client), FALSE);
 	g_return_val_if_fail (GDA_IS_SERVER_OPERATION (op), FALSE);
 
-	prv = find_or_load_provider (client, provider);
-	if (prv && prv->provider) 
-		return gda_server_provider_perform_operation (prv->provider, NULL, 
-							      op, error);
+	provider = g_object_get_data (G_OBJECT (op), "_gda_provider_name");
+	if (provider) 
+		return gda_server_provider_perform_operation (provider, NULL, op, error);
 	else {
-		g_set_error (error, GDA_CLIENT_ERROR, 0, 
-			     _("Could not find provider %s in the current setup"), provider); 
+		g_set_error (error, GDA_CLIENT_ERROR, GDA_CLIENT_GENERAL_ERROR, 
+			     _("Could not find operation's associated provider, "
+			       "did you use gda_client_prepare_drop_database() ?")); 
 		return FALSE;
 	}
 }
