@@ -21,8 +21,18 @@
 #ifndef __GDA_ENUMS__
 #define __GDA_ENUMS__
 
+/* Isolation state of a transaction */
+typedef enum {
+	GDA_TRANSACTION_ISOLATION_UNKNOWN,
+	GDA_TRANSACTION_ISOLATION_READ_COMMITTED,
+	GDA_TRANSACTION_ISOLATION_READ_UNCOMMITTED,
+	GDA_TRANSACTION_ISOLATION_REPEATABLE_READ,
+	GDA_TRANSACTION_ISOLATION_SERIALIZABLE
+} GdaTransactionIsolation;
+
 /* status of a value */
 typedef enum  {
+	GDA_VALUE_ATTR_NONE           = 0,
         GDA_VALUE_ATTR_IS_NULL        = 1 << 0,
         GDA_VALUE_ATTR_CAN_BE_NULL    = 1 << 1,
         GDA_VALUE_ATTR_IS_DEFAULT     = 1 << 2,
@@ -32,7 +42,8 @@ typedef enum  {
         GDA_VALUE_ATTR_DATA_NON_VALID = 1 << 6,
         GDA_VALUE_ATTR_HAS_VALUE_ORIG = 1 << 7,
 	GDA_VALUE_ATTR_NO_MODIF       = 1 << 8,
-} GValueAttribute;
+	GDA_VALUE_ATTR_UNUSED         = 1 << 9
+} GdaValueAttribute;
 
 /* different possible types for a GdaGraph object */
 typedef enum {
