@@ -42,13 +42,13 @@
 #endif
 
 /**
- * g_type_to_string
+ * gda_g_type_to_string
  * @type: Type to convert from.
  *
  * Returns: the string representing the given #GType.
  */
 const gchar *
-g_type_to_string (GType type)
+gda_g_type_to_string (GType type)
 {
 	if (type == GDA_TYPE_NULL)
 		return "null";
@@ -57,13 +57,13 @@ g_type_to_string (GType type)
 }
 
 /**
- * g_type_from_string
- * @str: the name of a #GType, as returned by g_type_to_string().
+ * gda_g_type_from_string
+ * @str: the name of a #GType, as returned by gda_g_type_to_string().
  *
  * Returns: the #GType represented by the given @str.
  */
 GType
-g_type_from_string (const gchar *str)
+gda_g_type_from_string (const gchar *str)
 {
 	GType type;
 	g_return_val_if_fail (str != NULL, G_TYPE_INVALID);
@@ -81,14 +81,14 @@ g_type_from_string (const gchar *str)
 }
 
 /**
- * gda_default_escape_chars
+ * gda_default_escape_string
  * @string: string to escape
  *
  * Escapes @string to make it understandable by a DBMS. The escape method is very common and replaces any
  * occurence of "'" with "\'" and "\" with "\\".
  */
 gchar *
-gda_default_escape_chars (const gchar *string)
+gda_default_escape_string (const gchar *string)
 {
 	gchar *ptr, *ret, *retptr;
 	gint size;
@@ -128,16 +128,16 @@ gda_default_escape_chars (const gchar *string)
 }
 
 /**
- * gda_default_unescape_chars
+ * gda_default_unescape_string
  * @string: string to unescape
  *
- * Do the reverse of gda_default_escape_chars(): transforms any "\'" into "'" and any
+ * Do the reverse of gda_default_escape_string(): transforms any "\'" into "'" and any
  * "\\" into "\". 
  *
  * Returns: a new unescaped string, or %NULL in an error was found in @string
  */
 gchar *
-gda_default_unescape_chars (const gchar *string)
+gda_default_unescape_string (const gchar *string)
 {
 	glong total;
 	gchar *ptr;
@@ -278,10 +278,10 @@ gda_file_save (const gchar *filename, const gchar *buffer, gint len)
 }
 
 /**
- * utility_table_field_attrs_stringify
+ * gda_utility_table_field_attrs_stringify
  */
 gchar *
-utility_table_field_attrs_stringify (guint attributes)
+gda_utility_table_field_attrs_stringify (GdaValueAttribute attributes)
 {
 	if (attributes & FIELD_AUTO_INCREMENT)
 		return g_strdup ("AUTO_INCREMENT");
@@ -290,10 +290,10 @@ utility_table_field_attrs_stringify (guint attributes)
 }
 
 /**
- * utility_table_field_attrs_parse
+ * gda_utility_table_field_attrs_parse
  */
 guint
-utility_table_field_attrs_parse (const gchar *str)
+gda_utility_table_field_attrs_parse (const gchar *str)
 {
 	if (!str)
 		return 0;
@@ -306,7 +306,7 @@ utility_table_field_attrs_parse (const gchar *str)
 
 
 /**
- * utility_build_encoded_id
+ * gda_utility_build_encoded_id
  *
  * Creates a BASE64 kind encoded string. It's not really a BASE64 because:
  * - the characters + and / of BASE64 are replaced with - and _
@@ -321,7 +321,7 @@ to_uchar (gchar ch)
 }
 
 gchar *
-utility_build_encoded_id (const gchar *prefix, const gchar *id)
+gda_utility_build_encoded_id (const gchar *prefix, const gchar *id)
 {
 	const gchar conv[64] = 
 		"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_";
@@ -516,16 +516,23 @@ static const signed char b64[0x100] = {
   B64 (252), B64 (253), B64 (254), B64 (255)
 };
 
-#define isbase64(x) ((to_uchar (x) <= 255) && (0 <= b64[to_uchar (x)]))
+/* This is the previous version:
+ * It caused a warning: "comparison is always true due to limited range of data type"
+ *
+ * #define isbase64(x) ((to_uchar (x) <= 255) && (0 <= b64[to_uchar (x)]))
+ *
+ * murrayc
+ */
+#define isbase64(x) ((0 <= b64[to_uchar (x)]))
 
 
 /**
- * utility_build_decoded_id
+ * gda_utility_build_decoded_id
  *
- * Reverse of utility_build_encoded_id()
+ * Reverse of gda_utility_build_encoded_id()
  */
 gchar *
-utility_build_decoded_id (const gchar *prefix, const gchar *id)
+gda_utility_build_decoded_id (const gchar *prefix, const gchar *id)
 {
 	gchar *str;
 	gchar *out;
@@ -577,7 +584,7 @@ utility_build_decoded_id (const gchar *prefix, const gchar *id)
 
 
 /**
- * utility_check_data_model
+ * gda_utility_check_data_model
  * @model: a #GdaDataModel object
  * @nbcols: the minimum requested number of columns
  * @Varargs: @nbcols arguments of type GType or -1 (if any data type is accepted)
@@ -587,7 +594,7 @@ utility_build_decoded_id (const gchar *prefix, const gchar *id)
  * Returns: TRUE if the data model's columns match the provided data types and number
  */
 gboolean
-utility_check_data_model (GdaDataModel *model, gint nbcols, ...)
+gda_utility_check_data_model (GdaDataModel *model, gint nbcols, ...)
 {
 	gboolean retval = TRUE;
 	gint i;
@@ -618,7 +625,7 @@ utility_check_data_model (GdaDataModel *model, gint nbcols, ...)
 					retval = FALSE;
 #ifdef GDA_DEBUG
 					g_print ("Column %d: Expected %s, got %s\n",
-						 i, g_type_to_string (rtype), g_type_to_string (mtype));
+						 i, gda_g_type_to_string (rtype), gda_g_type_to_string (mtype));
 #endif
 				}
 			}
@@ -633,7 +640,7 @@ utility_check_data_model (GdaDataModel *model, gint nbcols, ...)
 }
 
 /**
- * utility_data_model_dump_data_to_xml
+ * gda_utility_data_model_dump_data_to_xml
  * @model: 
  * @cols: an array containing which columns of @model will be exported, or %NULL for all columns
  * @nb_cols: the number of columns in @cols
@@ -644,7 +651,7 @@ utility_check_data_model (GdaDataModel *model, gint nbcols, ...)
  * Dump the data in a #GdaDataModel into a xmlNodePtr (as used in libxml).
  */
 void
-utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent, 
+gda_utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent, 
 				     const gint *cols, gint nb_cols, 
 				     const gint *rows, gint nb_rows,
 				     gboolean use_col_ids)
@@ -690,9 +697,9 @@ utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent,
 		xmlNodePtr row, data, field;
 		gint r, c;
 
-		data = xmlNewChild (parent, NULL, "gda_array_data", NULL);
+		data = xmlNewChild (parent, NULL, (xmlChar*)"gda_array_data", NULL);
 		for (r = 0; r < nrows; r++) {
-			row = xmlNewChild (data, NULL, "gda_array_row", NULL);
+			row = xmlNewChild (data, NULL,  (xmlChar*)"gda_array_row", NULL);
 			for (c = 0; c < rnb_cols; c++) {
 				GValue *value;
 				gchar *str;
@@ -707,13 +714,13 @@ utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent,
 						str = gda_value_stringify (value);
 				}
 				if (!use_col_ids) 
-					field = xmlNewChild (row, NULL, "gda_value", str);
+					field = xmlNewChild (row, NULL,  (xmlChar*)"gda_value", (xmlChar*)str);
 				else {
-					field = xmlNewChild (row, NULL, "gda_array_value", str);
-					xmlSetProp (field, "colid", col_ids [c]);
+					field = xmlNewChild (row, NULL,  (xmlChar*)"gda_array_value", (xmlChar*)str);
+					xmlSetProp(field, (xmlChar*)"colid",  (xmlChar*)col_ids [c]);
 				}
 				if (!str)
-					xmlSetProp (field, "isnull", "t");
+					xmlSetProp(field,  (xmlChar*)"isnull", (xmlChar*)"t");
 
 				g_free (str);
 			}
@@ -729,7 +736,7 @@ utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent,
 }
 
 /**
- * utility_parameter_load_attributes
+ * gda_utility_parameter_load_attributes
  * @param:
  * @node: an xmlNodePtr with a &lt;parameter&gt; tag
  * @sources: a list of #GdaDataModel
@@ -737,7 +744,7 @@ utility_data_model_dump_data_to_xml (GdaDataModel *model, xmlNodePtr parent,
  * WARNING: may set the "source" custom string property 
  */
 void
-utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList *sources)
+gda_utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList *sources)
 {
 	xmlChar *str;
 	xmlNodePtr vnode;
@@ -745,18 +752,18 @@ utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList
 	/* set properties from the XML spec */
 	str = xmlGetProp (node, BAD_CAST "id");
 	if (str) {
-		g_object_set (G_OBJECT (param), "string_id", str, NULL);
+		g_object_set (G_OBJECT (param), "string_id", (gchar*)str, NULL);
 		xmlFree (str);
 	}	
 
 	str = xmlGetProp (node, BAD_CAST "name");
 	if (str) {
-		gda_object_set_name (GDA_OBJECT (param), str);
+		gda_object_set_name (GDA_OBJECT (param), (gchar*)str);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, BAD_CAST "descr");
 	if (str) {
-		gda_object_set_description (GDA_OBJECT (param), str);
+		gda_object_set_description (GDA_OBJECT (param), (gchar*)str);
 		xmlFree (str);
 	}
 	str = xmlGetProp (node, BAD_CAST "nullok");
@@ -768,20 +775,20 @@ utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList
 		gda_parameter_set_not_null (param, FALSE);
 	str = xmlGetProp (node, BAD_CAST "plugin");
 	if (str) {
-		g_object_set (G_OBJECT (param), "entry_plugin", str, NULL);
+		g_object_set (G_OBJECT (param), "entry_plugin", (gchar*)str, NULL);
 		xmlFree (str);
 	}
 	
 	str = xmlGetProp (node, BAD_CAST "source");
 	if (str) 
-		g_object_set_data_full (G_OBJECT (param), "source", str, g_free);
+		g_object_set_data_full (G_OBJECT (param), "source", (gchar*)str, g_free);
 
 	/* set restricting source if specified */
 	if (str && sources) {
 		gchar *ptr1, *ptr2 = NULL, *tok;
 		gchar *source;
 			
-		source = g_strdup (str);
+		source = g_strdup ((gchar*)str);
 		ptr1 = strtok_r (source, ":", &tok);
 		if (ptr1)
 			ptr2 = strtok_r (NULL, ":", &tok);
@@ -836,20 +843,20 @@ utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList
 				continue;
 			}
 
-			if (strcmp (vnode->name, "gda_value")) {
+			if (strcmp ((gchar*)vnode->name, "gda_value")) {
 				vnode = vnode->next;
 				continue;
 			}
 
 			/* don't care about entries for the wrong locale */
-			this_lang = xmlGetProp (vnode, "lang");
-			if (this_lang && strncmp (this_lang, lang, strlen (this_lang))) {
+			this_lang = xmlGetProp(vnode, (xmlChar*)"lang");
+			if (this_lang && strncmp ((gchar*)this_lang, lang, strlen ((gchar*)this_lang))) {
 				g_free (this_lang);
 				vnode = vnode->next;
 				continue;
 			}
 			
-			isnull = xmlGetProp (vnode, "isnull");
+			isnull = xmlGetProp(vnode, (xmlChar*)"isnull");
 			if (isnull) {
 				if ((*isnull == 'f') || (*isnull == 'F')) {
 					xmlFree (isnull);
@@ -861,7 +868,7 @@ utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList
 				GValue *value;
 
 				value = g_new0 (GValue, 1);
-				if (! gda_value_set_from_string (value, xmlNodeGetContent (vnode), gdatype)) {
+				if (! gda_value_set_from_string (value, (gchar*)xmlNodeGetContent (vnode), gdatype)) {
 					/* error */
 					g_free (value);
 				}
@@ -895,7 +902,7 @@ utility_parameter_load_attributes (GdaParameter *param, xmlNodePtr node, GSList
  * Returns: a #GdaDictType, or %NULL if it was not possible to find and create one
  */
 GdaDictType *
-utility_find_or_create_data_type (GdaDict *dict, GdaServerProvider *prov, GdaConnection *cnc, 
+gda_utility_find_or_create_data_type (GdaDict *dict, GdaServerProvider *prov, GdaConnection *cnc, 
 				  const gchar *dbms_type, const gchar *g_type, gboolean *created)
 {
 	GdaDictType *dtype = NULL;
@@ -913,7 +920,7 @@ utility_find_or_create_data_type (GdaDict *dict, GdaServerProvider *prov, GdaCon
 		if (g_type) {
 			GType gtype;
 			
-			gtype = g_type_from_string (g_type);
+			gtype = gda_g_type_from_string (g_type);
 			if (prov) {
 				const gchar *deftype;
 				
